Chapter 18: Forecasting + planning basics
=========================================

**Status:** Planned (coming soon).

What this chapter covers
------------------------

- Planning model hooks (budgets/forecast)
- Where to go next (capstones/extensions)

Planned outputs
---------------

- Runner module (planned): ``ledgerloom.chapters.ch18_forecasting_planning_basics``
- Artifacts under ``outputs/ledgerloom/ch18``
- Golden-file tests for determinism